Struct lattices::Bottom

source ·
#[repr(transparent)]
pub struct Bottom<Inner>(pub Option<Inner>);
Wraps a lattice in Option, treating None as a new bottom element which compares as less than to all other values.

This can be used for giving a sensible default/bottom element to lattices that don’t necessarily have one.

Tuple Fields

0: Option<Inner>

Implementations

source

impl<Inner> Bottom<Inner>

source

pub fn new(val: Inner) -> Self

Create a new Bottom lattice instance from a value.

source

pub fn new_from(val: impl Into<Inner>) -> Self

Create a new Bottom lattice instance from a value using Into.