pub trait LatticeFrom<Other> {
// Required method
fn lattice_from(other: Other) -> Self;
}Expand description
Same as From but for lattices.
This should only be implemented between different representations of the same lattice type. This should recursively convert nested lattice types, but not non-lattice (“scalar”) types.
Required Methods
Sourcefn lattice_from(other: Other) -> Self
fn lattice_from(other: Other) -> Self
Convert from the Other lattice into Self.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl LatticeFrom<()> for ()
impl LatticeFrom<()> for ()
fn lattice_from(other: Self) -> Self
Implementors
impl<Inner, Other> LatticeFrom<WithBot<Other>> for WithBot<Inner>where
Inner: LatticeFrom<Other>,
impl<Inner, Other> LatticeFrom<WithTop<Other>> for WithTop<Inner>where
Inner: LatticeFrom<Other>,
impl<KeySelf, KeyOther, ValSelf, ValOther> LatticeFrom<DomPair<KeyOther, ValOther>> for DomPair<KeySelf, ValSelf>where
KeySelf: LatticeFrom<KeyOther>,
ValSelf: LatticeFrom<ValOther>,
impl<LatA, LatB, __LatAOther, __LatBOther> LatticeFrom<Pair<__LatAOther, __LatBOther>> for Pair<LatA, LatB>where
LatA: LatticeFrom<__LatAOther>,
LatB: LatticeFrom<__LatBOther>,
impl<LatSelf, LatOther> LatticeFrom<VecUnion<LatOther>> for VecUnion<LatSelf>where
LatSelf: LatticeFrom<LatOther>,
Available on crate feature
alloc only.impl<MapSelf, MapOther, K, ValSelf, ValOther, TombstoneSetSelf, TombstoneSetOther> LatticeFrom<MapUnionWithTombstones<MapOther, TombstoneSetOther>> for MapUnionWithTombstones<MapSelf, TombstoneSetSelf>where
MapSelf: Keyed<Key = K, Item = ValSelf> + FromIterator<(K, ValSelf)>,
MapOther: IntoIterator<Item = (K, ValOther)>,
ValSelf: LatticeFrom<ValOther>,
TombstoneSetSelf: FromIterator<K>,
TombstoneSetOther: IntoIterator<Item = K>,
impl<MapSelf, MapOther, K, ValSelf, ValOther> LatticeFrom<MapUnion<MapOther>> for MapUnion<MapSelf>where
MapSelf: Keyed<Key = K, Item = ValSelf> + FromIterator<(K, ValSelf)>,
MapOther: IntoIterator<Item = (K, ValOther)>,
ValSelf: LatticeFrom<ValOther>,
impl<MapSelf, MapOther, K> LatticeFrom<UnionFind<MapOther>> for UnionFind<MapSelf>where
MapSelf: Keyed<Key = K, Item = Cell<K>> + FromIterator<(K, Cell<K>)>,
MapOther: IntoIterator<Item = (K, Cell<K>)>,
K: Copy + Eq,
Available on crate feature
std only.