pub trait LatticeOrd<Rhs = Self>: PartialOrd<Rhs> { }Expand description
Trait for lattice partial order comparison PartialOrd is implemented for many things, this trait can be used to require the type be a lattice.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
impl LatticeOrd for ()
Implementors
impl<Head, Node> LatticeOrd for GhtInner<Head, Node>where
Self: PartialOrd<GhtInner<Head, Node>>,
Head: Clone,
Node: GeneralizedHashTrieNode,
Node::Storage: VariadicSet<Schema = Node::Schema>,
Available on crate feature
std only.impl<Inner, Other> LatticeOrd<WithBot<Other>> for WithBot<Inner>where
Self: PartialOrd<WithBot<Other>>,
impl<Inner, Other> LatticeOrd<WithTop<Other>> for WithTop<Inner>where
Self: PartialOrd<WithTop<Other>>,
impl<KeySelf, KeyOther, ValSelf, ValOther> LatticeOrd<DomPair<KeyOther, ValOther>> for DomPair<KeySelf, ValSelf>where
Self: PartialOrd<DomPair<KeyOther, ValOther>>,
impl<LatA, LatB, __LatAOther, __LatBOther> LatticeOrd<Pair<__LatAOther, __LatBOther>> for Pair<LatA, LatB>where
LatA: PartialOrd<__LatAOther>,
LatB: PartialOrd<__LatBOther>,
impl<LatSelf, LatOther> LatticeOrd<VecUnion<LatOther>> for VecUnion<LatSelf>where
Self: PartialOrd<VecUnion<LatOther>>,
Available on crate feature
alloc only.impl<MapSelf, MapOther, TombstoneSetSelf, TombstoneSetOther> LatticeOrd<MapUnionWithTombstones<MapOther, TombstoneSetOther>> for MapUnionWithTombstones<MapSelf, TombstoneSetSelf>where
Self: PartialOrd<MapUnionWithTombstones<MapOther, TombstoneSetOther>>,
impl<MapSelf, MapOther> LatticeOrd<MapUnion<MapOther>> for MapUnion<MapSelf>where
Self: PartialOrd<MapUnion<MapOther>>,
impl<MapSelf, MapOther> LatticeOrd<UnionFind<MapOther>> for UnionFind<MapSelf>where
Self: PartialOrd<UnionFind<MapOther>>,
Available on crate feature
std only.impl<Schema, SuffixSchema, Storage> LatticeOrd for GhtLeaf<Schema, SuffixSchema, Storage>
Available on crate feature
std only.